@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,8 +14,7 @@ class SMTPMailTransportPlugin : public MailTransport::TransportAbstractPlugin
 {
     Q_OBJECT
 public:
-    explicit SMTPMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & = {
-    });
+    explicit SMTPMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & = {});
     ~SMTPMailTransportPlugin() override;
 
     Q_REQUIRED_RESULT QVector<MailTransport::TransportAbstractPluginInfo> names() const override;
