@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef TRANSPORTPLUGINMANAGER_H
 #define TRANSPORTPLUGINMANAGER_H
 
-#include <QObject>
 #include "kmailtransport_private_export.h"
-namespace MailTransport {
+#include <QObject>
+namespace MailTransport
+{
 class TransportAbstractPlugin;
 class TransportPluginManagerPrivate;
 class KMAILTRANSPORT_TESTS_EXPORT TransportPluginManager : public QObject
@@ -17,7 +18,7 @@ class KMAILTRANSPORT_TESTS_EXPORT TransportPluginManager : public QObject
     Q_OBJECT
 public:
     explicit TransportPluginManager(QObject *parent = nullptr);
-    ~TransportPluginManager();
+    ~TransportPluginManager() override;
 
     static TransportPluginManager *self();
 
